import unittest

from tracklr.main import TracklrApp
from tracklr.init import Init


class TestPDFCommand(unittest.TestCase):
    def test_init(self):
        app = TracklrApp()
        init = Init(app, None)



import unittest

from tracklr.main import TracklrApp
from tracklr.group import Group


class TestGroupCommand(unittest.TestCase):
    def test_group(self):
        app = TracklrApp()
        group = Group(app, None)
